@@ -372,14 +372,19 @@ class ImageDataSource(DataSource):
         returned by get_sample().
     """
 
-    image_size_pixels: InitVar[int]
+    image_size_pixels_height: InitVar[int]
+    image_size_pixels_width: InitVar[int]
     meters_per_pixel: InitVar[int]
 
-    def __post_init__(self, image_size_pixels: int, meters_per_pixel: int):
+    def __post_init__(
+        self, image_size_pixels_height: int, image_size_pixels_width: int, meters_per_pixel: int
+    ):
         """Post Init"""
         super().__post_init__()
-        self._square = square.Square(
-            size_pixels=image_size_pixels, meters_per_pixel=meters_per_pixel
+        self._rectangle = square.Rectangle(
+            size_pixels_height=image_size_pixels_height,
+            size_pixels_width=image_size_pixels_width,
+            meters_per_pixel=meters_per_pixel,
         )
 
 
@@ -403,9 +408,11 @@ class ZarrDataSource(ImageDataSource):
     channels: Iterable[str] = None
     consolidated: bool = True
 
-    def __post_init__(self, image_size_pixels: int, meters_per_pixel: int):
+    def __post_init__(
+        self, image_size_pixels_height: int, image_size_pixels_width: int, meters_per_pixel: int
+    ):
         """Post init"""
-        super().__post_init__(image_size_pixels, meters_per_pixel)
+        super().__post_init__(image_size_pixels_height, image_size_pixels_width, meters_per_pixel)
         self._data = None
 
     def check_input_paths_exist(self) -> None:
@@ -442,7 +449,7 @@ class ZarrDataSource(ImageDataSource):
         )
 
         selected_data = self._get_time_slice(t0_datetime_utc)
-        bounding_box = self._square.bounding_box_centered_on(
+        bounding_box = self._rectangle.bounding_box_centered_on(
             x_center_osgb=x_center_osgb, y_center_osgb=y_center_osgb
         )
         selected_data = selected_data.sel(
@@ -453,7 +460,8 @@ class ZarrDataSource(ImageDataSource):
         # selected_sat_data is likely to have 1 too many pixels in x and y
         # because sel(x=slice(a, b)) is [a, b], not [a, b).  So trim:
         selected_data = selected_data.isel(
-            x_osgb=slice(0, self._square.size_pixels), y_osgb=slice(0, self._square.size_pixels)
+            x_osgb=slice(0, self._rectangle.size_pixels_width),
+            y_osgb=slice(0, self._rectangle.size_pixels_height),
         )
 
         selected_data = self._post_process_example(selected_data, t0_datetime_utc)
